package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class Nonempty_DecNodeSetBody_PCList {
  protected DecNodeSetBody it;
  public DecNodeSetBody get_it() { return it; }
  public void set_it(DecNodeSetBody new_it) { it = new_it; }
  protected Nonempty_DecNodeSetBody_PCList next;
  public Nonempty_DecNodeSetBody_PCList get_next() { return next; }
  public void set_next(Nonempty_DecNodeSetBody_PCList new_next) { next = new_next; }
  public Nonempty_DecNodeSetBody_PCList() { super(); }
  public Nonempty_DecNodeSetBody_PCList(DecNodeSetBody it, Nonempty_DecNodeSetBody_PCList next) {
    super();
    set_it(it);
    set_next(next);
  }
  public static Nonempty_DecNodeSetBody_PCList parse(java.io.Reader in) throws ParseException { return new Parser(in)._Nonempty_DecNodeSetBody_PCList(); }
  public static Nonempty_DecNodeSetBody_PCList parse(java.io.InputStream in) throws ParseException { return new Parser(in)._Nonempty_DecNodeSetBody_PCList(); }
  public static Nonempty_DecNodeSetBody_PCList parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_it(this, it);
    it.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_it(this, it);
    if (next != null) {
      ((UniversalVisitor) _v_).before_next(this, next);
      next.universal_trv0(_v_);
      ((UniversalVisitor) _v_).after_next(this, next);
    }
    universal_trv0_aft(_v_);
  }

}
