package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
abstract class UniversalVisitor {
  public UniversalVisitor() {
    super();
  }
  public void start() { }
  public void before(AspectFile host) { }
  public void before_aspects(AspectFile source, Aspects dest) { }
  public void before(Aspect host) { }
  public void before_aspectbody(Aspect source, AspectBody dest) { }
  public void before(AspectBody host) { }
  public void before(AspectCD host) { }
  public void before_aspectname(AspectCD source, AspectName dest) { }
  public void before_cdbody(AspectCD source, CDBody dest) { }
  public void before(AspectTV host) { }
  public void before_aspectname(AspectTV source, AspectName dest) { }
  public void before_tvbody(AspectTV source, TVBody dest) { }
  public void before(TVBody host) { }
  public void before_tvdeclarations(TVBody source, TVDeclarations dest) { }
  public void before(TVDeclaration host) { }
  public void before_tvdeclarationbody(TVDeclaration source, TVDeclarationBody dest) { }
  public void before(TVDeclarationBody host) { }
  public void before(DecChosen host) { }
  public void before_decchosenbody(DecChosen source, DecChosenBody dest) { }
  public void before(DecChosenBody host) { }
  public void before(ChosenSelector host) { }
  public void before_ident(ChosenSelector source, Ident dest) { }
  public void before(ChosenCD host) { }
  public void before_ident(ChosenCD source, Ident dest) { }
  public void before(DecStrategy host) { }
  public void before_decname(DecStrategy source, DecName dest) { }
  public void before_strategyexpression(DecStrategy source, StrategyExpression dest) { }
  public void before(DecNodeSet host) { }
  public void before_nodesubsetname(DecNodeSet source, NodeSubsetName dest) { }
  public void before_decnodesetbody(DecNodeSet source, DecNodeSetBody dest) { }
  public void before(NodeSubsetName host) { }
  public void before_ident(NodeSubsetName source, Ident dest) { }
  public void before(DecNodeSetBody host) { }
  public void before(Simple host) { }
  public void before(BCompound host) { }
  public void before_op(BCompound source, BinaryOp dest) { }
  public void before_args(BCompound source, DecNodeSetBody_PCList dest) { }
  public void before(UCompound host) { }
  public void before_op(UCompound source, UnaryOp dest) { }
  public void before_arg(UCompound source, DecNodeSetBody dest) { }
  public void before(Operator host) { }
  public void before(BinaryOp host) { }
  public void before(UnaryOp host) { }
  public void before(Union host) { }
  public void before(Intersection host) { }
  public void before(Complement host) { }
  public void before(ClassNameSet host) { }
  public void before_items(ClassNameSet source, ClassName_BCList dest) { }
  public void before(GraphNodes host) { }
  public void before_decname(GraphNodes source, DecName dest) { }
  public void before(GraphNodeRegExp host) { }
  public void before_classnameprefix(GraphNodeRegExp source, ClassNamePrefix dest) { }
  public void before_wildcard(GraphNodeRegExp source, WildCard dest) { }
  public void before(WildCard host) { }
  public void before(AspectName host) { }
  public void before_ident(AspectName source, Ident dest) { }
  public void before(ClassNamePrefix host) { }
  public void before_ident(ClassNamePrefix source, Ident dest) { }
  public void before(DecName host) { }
  public void before_ident(DecName source, Ident dest) { }
  public void before(CDBody host) { }
  public void before_text(CDBody source, Text dest) { }
  public void before(Regexp host) { }
  public void before(Aspects host) { }
  public void before_aspect_list(Aspects source, Aspect_List dest) { }
  public void before(TVDeclarations host) { }
  public void before_tvdeclaration_list(TVDeclarations source, TVDeclaration_List dest) { }
  public void before(Main host) { }
  public void before(StrategyExpression host) { }
  public void before_strategy(StrategyExpression source, Strategy dest) { }
  public void before(Strategy host) { }
  public void before(SimpleStrategy host) { }
  public void before_parsedNameMap(SimpleStrategy source, NameMap dest) { }
  public void before(StrategyGraph host) { }
  public void before_edges(StrategyGraph source, SGEdge_SList dest) { }
  public void before(SGEdge host) { }
  public void before_sourcemarker(SGEdge source, SourceMarker dest) { }
  public void before_source(SGEdge source, GlobSpec dest) { }
  public void before_targetmarker(SGEdge source, TargetMarker dest) { }
  public void before_target(SGEdge source, GlobSpec dest) { }
  public void before_constraint(SGEdge source, NegativeConstraint dest) { }
  public void before(SourceMarker host) { }
  public void before(TargetMarker host) { }
  public void before(PathDirective host) { }
  public void before_source(PathDirective source, SourceDirective dest) { }
  public void before_constraint(PathDirective source, NegativeConstraint dest) { }
  public void before_segments(PathDirective source, PathSegment_List dest) { }
  public void before_target(PathDirective source, TargetDirective dest) { }
  public void before(SourceDirective host) { }
  public void before_sources(SourceDirective source, ClassGlobSpec dest) { }
  public void before(From host) { }
  public void before(PathSegment host) { }
  public void before_node(PathSegment source, PositiveConstraint dest) { }
  public void before_constraint(PathSegment source, NegativeConstraint dest) { }
  public void before(Constraint host) { }
  public void before_glob(Constraint source, GlobSpec dest) { }
  public void before(PositiveConstraint host) { }
  public void before(Through host) { }
  public void before(Via host) { }
  public void before(NegativeConstraint host) { }
  public void before(Bypassing host) { }
  public void before(OnlyThrough host) { }
  public void before(TargetDirective host) { }
  public void before_targets(TargetDirective source, ClassGlobSpec dest) { }
  public void before(To host) { }
  public void before(ToStop host) { }
  public void before(StrategyCombination host) { }
  public void before_first(StrategyCombination source, Strategy dest) { }
  public void before_rest(StrategyCombination source, Strategy_Commalist dest) { }
  public void before(Join host) { }
  public void before(Merge host) { }
  public void before(Intersect host) { }
  public void before(StrategyReference host) { }
  public void before_ident(StrategyReference source, Ident dest) { }
  public void before(SymbolicNameMap host) { }
  public void before(NameMap host) { }
  public void before_bindings(NameMap source, NameBinding_Commalist dest) { }
  public void before(NameBinding host) { }
  public void before_sgName(NameBinding source, Name dest) { }
  public void before_cgNames(NameBinding source, ClassGlobSpec dest) { }
  public void before(GlobSpec host) { }
  public void before(OneGlob host) { }
  public void before_glob(OneGlob source, Glob dest) { }
  public void before(GlobSet host) { }
  public void before_globs(GlobSet source, Glob_Commalist dest) { }
  public void before(Glob host) { }
  public void before(EdgeGlob host) { }
  public void before(ClassGlob host) { }
  public void before_name(ClassGlob source, ClassNameGlob dest) { }
  public void before(PartGlob host) { }
  public void before_source(PartGlob source, SourceGlob dest) { }
  public void before_name(PartGlob source, PartNameGlob dest) { }
  public void before_target(PartGlob source, TargetGlob dest) { }
  public void before(SubclassGlob host) { }
  public void before_source(SubclassGlob source, SourceGlob dest) { }
  public void before_target(SubclassGlob source, TargetGlob dest) { }
  public void before(SuperclassGlob host) { }
  public void before_source(SuperclassGlob source, SourceGlob dest) { }
  public void before_target(SuperclassGlob source, TargetGlob dest) { }
  public void before(SourceGlob host) { }
  public void before_name(SourceGlob source, ClassNameGlob dest) { }
  public void before(TargetGlob host) { }
  public void before_name(TargetGlob source, ClassNameGlob dest) { }
  public void before(ClassNameGlob host) { }
  public void before(ClassNameExact host) { }
  public void before_classname(ClassNameExact source, ClassName dest) { }
  public void before(AnyClass host) { }
  public void before(PartNameGlob host) { }
  public void before(PartNameExact host) { }
  public void before_partname(PartNameExact source, PartName dest) { }
  public void before(AnyPart host) { }
  public void before(ClassGlobSpec host) { }
  public void before(OneClassGlob host) { }
  public void before_classglob(OneClassGlob source, ClassGlob dest) { }
  public void before(ClassGlobSet host) { }
  public void before_globs(ClassGlobSet source, ClassGlob_Commalist dest) { }
  public void before(ClassName host) { }
  public void before_name(ClassName source, Name dest) { }
  public void before(PartName host) { }
  public void before_name(PartName source, Ident dest) { }
  public void before(Name host) { }
  public void before_first(Name source, Nonempty_Name dest) { }
  public void before(DecNodeSetBody_PCList host) { }
  public void before_first(DecNodeSetBody_PCList source, Nonempty_DecNodeSetBody_PCList dest) { }
  public void before(ClassName_BCList host) { }
  public void before_first(ClassName_BCList source, Nonempty_ClassName_BCList dest) { }
  public void before(Aspect_List host) { }
  public void before_first(Aspect_List source, Nonempty_Aspect_List dest) { }
  public void before(TVDeclaration_List host) { }
  public void before_first(TVDeclaration_List source, Nonempty_TVDeclaration_List dest) { }
  public void before(SGEdge_SList host) { }
  public void before_first(SGEdge_SList source, Nonempty_SGEdge_SList dest) { }
  public void before(PathSegment_List host) { }
  public void before_first(PathSegment_List source, Nonempty_PathSegment_List dest) { }
  public void before(Strategy_Commalist host) { }
  public void before_first(Strategy_Commalist source, Nonempty_Strategy_Commalist dest) { }
  public void before(NameBinding_Commalist host) { }
  public void before_first(NameBinding_Commalist source, Nonempty_NameBinding_Commalist dest) { }
  public void before(Glob_Commalist host) { }
  public void before_first(Glob_Commalist source, Nonempty_Glob_Commalist dest) { }
  public void before(ClassGlob_Commalist host) { }
  public void before_first(ClassGlob_Commalist source, Nonempty_ClassGlob_Commalist dest) { }
  public void before(Nonempty_Name host) { }
  public void before_it(Nonempty_Name source, Ident dest) { }
  public void before_next(Nonempty_Name source, Nonempty_Name dest) { }
  public void before(Nonempty_DecNodeSetBody_PCList host) { }
  public void before_it(Nonempty_DecNodeSetBody_PCList source, DecNodeSetBody dest) { }
  public void before_next(Nonempty_DecNodeSetBody_PCList source, Nonempty_DecNodeSetBody_PCList dest) { }
  public void before(Nonempty_ClassName_BCList host) { }
  public void before_it(Nonempty_ClassName_BCList source, ClassName dest) { }
  public void before_next(Nonempty_ClassName_BCList source, Nonempty_ClassName_BCList dest) { }
  public void before(Nonempty_Aspect_List host) { }
  public void before_it(Nonempty_Aspect_List source, Aspect dest) { }
  public void before_next(Nonempty_Aspect_List source, Nonempty_Aspect_List dest) { }
  public void before(Nonempty_TVDeclaration_List host) { }
  public void before_it(Nonempty_TVDeclaration_List source, TVDeclaration dest) { }
  public void before_next(Nonempty_TVDeclaration_List source, Nonempty_TVDeclaration_List dest) { }
  public void before(Nonempty_SGEdge_SList host) { }
  public void before_it(Nonempty_SGEdge_SList source, SGEdge dest) { }
  public void before_next(Nonempty_SGEdge_SList source, Nonempty_SGEdge_SList dest) { }
  public void before(Nonempty_PathSegment_List host) { }
  public void before_it(Nonempty_PathSegment_List source, PathSegment dest) { }
  public void before_next(Nonempty_PathSegment_List source, Nonempty_PathSegment_List dest) { }
  public void before(Nonempty_Strategy_Commalist host) { }
  public void before_it(Nonempty_Strategy_Commalist source, Strategy dest) { }
  public void before_next(Nonempty_Strategy_Commalist source, Nonempty_Strategy_Commalist dest) { }
  public void before(Nonempty_NameBinding_Commalist host) { }
  public void before_it(Nonempty_NameBinding_Commalist source, NameBinding dest) { }
  public void before_next(Nonempty_NameBinding_Commalist source, Nonempty_NameBinding_Commalist dest) { }
  public void before(Nonempty_Glob_Commalist host) { }
  public void before_it(Nonempty_Glob_Commalist source, Glob dest) { }
  public void before_next(Nonempty_Glob_Commalist source, Nonempty_Glob_Commalist dest) { }
  public void before(Nonempty_ClassGlob_Commalist host) { }
  public void before_it(Nonempty_ClassGlob_Commalist source, ClassGlob dest) { }
  public void before_next(Nonempty_ClassGlob_Commalist source, Nonempty_ClassGlob_Commalist dest) { }
  public void after(AspectFile host) { }
  public void after_aspects(AspectFile source, Aspects dest) { }
  public void after(Aspect host) { }
  public void after_aspectbody(Aspect source, AspectBody dest) { }
  public void after(AspectBody host) { }
  public void after(AspectCD host) { }
  public void after_aspectname(AspectCD source, AspectName dest) { }
  public void after_cdbody(AspectCD source, CDBody dest) { }
  public void after(AspectTV host) { }
  public void after_aspectname(AspectTV source, AspectName dest) { }
  public void after_tvbody(AspectTV source, TVBody dest) { }
  public void after(TVBody host) { }
  public void after_tvdeclarations(TVBody source, TVDeclarations dest) { }
  public void after(TVDeclaration host) { }
  public void after_tvdeclarationbody(TVDeclaration source, TVDeclarationBody dest) { }
  public void after(TVDeclarationBody host) { }
  public void after(DecChosen host) { }
  public void after_decchosenbody(DecChosen source, DecChosenBody dest) { }
  public void after(DecChosenBody host) { }
  public void after(ChosenSelector host) { }
  public void after_ident(ChosenSelector source, Ident dest) { }
  public void after(ChosenCD host) { }
  public void after_ident(ChosenCD source, Ident dest) { }
  public void after(DecStrategy host) { }
  public void after_decname(DecStrategy source, DecName dest) { }
  public void after_strategyexpression(DecStrategy source, StrategyExpression dest) { }
  public void after(DecNodeSet host) { }
  public void after_nodesubsetname(DecNodeSet source, NodeSubsetName dest) { }
  public void after_decnodesetbody(DecNodeSet source, DecNodeSetBody dest) { }
  public void after(NodeSubsetName host) { }
  public void after_ident(NodeSubsetName source, Ident dest) { }
  public void after(DecNodeSetBody host) { }
  public void after(Simple host) { }
  public void after(BCompound host) { }
  public void after_op(BCompound source, BinaryOp dest) { }
  public void after_args(BCompound source, DecNodeSetBody_PCList dest) { }
  public void after(UCompound host) { }
  public void after_op(UCompound source, UnaryOp dest) { }
  public void after_arg(UCompound source, DecNodeSetBody dest) { }
  public void after(Operator host) { }
  public void after(BinaryOp host) { }
  public void after(UnaryOp host) { }
  public void after(Union host) { }
  public void after(Intersection host) { }
  public void after(Complement host) { }
  public void after(ClassNameSet host) { }
  public void after_items(ClassNameSet source, ClassName_BCList dest) { }
  public void after(GraphNodes host) { }
  public void after_decname(GraphNodes source, DecName dest) { }
  public void after(GraphNodeRegExp host) { }
  public void after_classnameprefix(GraphNodeRegExp source, ClassNamePrefix dest) { }
  public void after_wildcard(GraphNodeRegExp source, WildCard dest) { }
  public void after(WildCard host) { }
  public void after(AspectName host) { }
  public void after_ident(AspectName source, Ident dest) { }
  public void after(ClassNamePrefix host) { }
  public void after_ident(ClassNamePrefix source, Ident dest) { }
  public void after(DecName host) { }
  public void after_ident(DecName source, Ident dest) { }
  public void after(CDBody host) { }
  public void after_text(CDBody source, Text dest) { }
  public void after(Regexp host) { }
  public void after(Aspects host) { }
  public void after_aspect_list(Aspects source, Aspect_List dest) { }
  public void after(TVDeclarations host) { }
  public void after_tvdeclaration_list(TVDeclarations source, TVDeclaration_List dest) { }
  public void after(Main host) { }
  public void after(StrategyExpression host) { }
  public void after_strategy(StrategyExpression source, Strategy dest) { }
  public void after(Strategy host) { }
  public void after(SimpleStrategy host) { }
  public void after_parsedNameMap(SimpleStrategy source, NameMap dest) { }
  public void after(StrategyGraph host) { }
  public void after_edges(StrategyGraph source, SGEdge_SList dest) { }
  public void after(SGEdge host) { }
  public void after_sourcemarker(SGEdge source, SourceMarker dest) { }
  public void after_source(SGEdge source, GlobSpec dest) { }
  public void after_targetmarker(SGEdge source, TargetMarker dest) { }
  public void after_target(SGEdge source, GlobSpec dest) { }
  public void after_constraint(SGEdge source, NegativeConstraint dest) { }
  public void after(SourceMarker host) { }
  public void after(TargetMarker host) { }
  public void after(PathDirective host) { }
  public void after_source(PathDirective source, SourceDirective dest) { }
  public void after_constraint(PathDirective source, NegativeConstraint dest) { }
  public void after_segments(PathDirective source, PathSegment_List dest) { }
  public void after_target(PathDirective source, TargetDirective dest) { }
  public void after(SourceDirective host) { }
  public void after_sources(SourceDirective source, ClassGlobSpec dest) { }
  public void after(From host) { }
  public void after(PathSegment host) { }
  public void after_node(PathSegment source, PositiveConstraint dest) { }
  public void after_constraint(PathSegment source, NegativeConstraint dest) { }
  public void after(Constraint host) { }
  public void after_glob(Constraint source, GlobSpec dest) { }
  public void after(PositiveConstraint host) { }
  public void after(Through host) { }
  public void after(Via host) { }
  public void after(NegativeConstraint host) { }
  public void after(Bypassing host) { }
  public void after(OnlyThrough host) { }
  public void after(TargetDirective host) { }
  public void after_targets(TargetDirective source, ClassGlobSpec dest) { }
  public void after(To host) { }
  public void after(ToStop host) { }
  public void after(StrategyCombination host) { }
  public void after_first(StrategyCombination source, Strategy dest) { }
  public void after_rest(StrategyCombination source, Strategy_Commalist dest) { }
  public void after(Join host) { }
  public void after(Merge host) { }
  public void after(Intersect host) { }
  public void after(StrategyReference host) { }
  public void after_ident(StrategyReference source, Ident dest) { }
  public void after(SymbolicNameMap host) { }
  public void after(NameMap host) { }
  public void after_bindings(NameMap source, NameBinding_Commalist dest) { }
  public void after(NameBinding host) { }
  public void after_sgName(NameBinding source, Name dest) { }
  public void after_cgNames(NameBinding source, ClassGlobSpec dest) { }
  public void after(GlobSpec host) { }
  public void after(OneGlob host) { }
  public void after_glob(OneGlob source, Glob dest) { }
  public void after(GlobSet host) { }
  public void after_globs(GlobSet source, Glob_Commalist dest) { }
  public void after(Glob host) { }
  public void after(EdgeGlob host) { }
  public void after(ClassGlob host) { }
  public void after_name(ClassGlob source, ClassNameGlob dest) { }
  public void after(PartGlob host) { }
  public void after_source(PartGlob source, SourceGlob dest) { }
  public void after_name(PartGlob source, PartNameGlob dest) { }
  public void after_target(PartGlob source, TargetGlob dest) { }
  public void after(SubclassGlob host) { }
  public void after_source(SubclassGlob source, SourceGlob dest) { }
  public void after_target(SubclassGlob source, TargetGlob dest) { }
  public void after(SuperclassGlob host) { }
  public void after_source(SuperclassGlob source, SourceGlob dest) { }
  public void after_target(SuperclassGlob source, TargetGlob dest) { }
  public void after(SourceGlob host) { }
  public void after_name(SourceGlob source, ClassNameGlob dest) { }
  public void after(TargetGlob host) { }
  public void after_name(TargetGlob source, ClassNameGlob dest) { }
  public void after(ClassNameGlob host) { }
  public void after(ClassNameExact host) { }
  public void after_classname(ClassNameExact source, ClassName dest) { }
  public void after(AnyClass host) { }
  public void after(PartNameGlob host) { }
  public void after(PartNameExact host) { }
  public void after_partname(PartNameExact source, PartName dest) { }
  public void after(AnyPart host) { }
  public void after(ClassGlobSpec host) { }
  public void after(OneClassGlob host) { }
  public void after_classglob(OneClassGlob source, ClassGlob dest) { }
  public void after(ClassGlobSet host) { }
  public void after_globs(ClassGlobSet source, ClassGlob_Commalist dest) { }
  public void after(ClassName host) { }
  public void after_name(ClassName source, Name dest) { }
  public void after(PartName host) { }
  public void after_name(PartName source, Ident dest) { }
  public void after(Name host) { }
  public void after_first(Name source, Nonempty_Name dest) { }
  public void after(DecNodeSetBody_PCList host) { }
  public void after_first(DecNodeSetBody_PCList source, Nonempty_DecNodeSetBody_PCList dest) { }
  public void after(ClassName_BCList host) { }
  public void after_first(ClassName_BCList source, Nonempty_ClassName_BCList dest) { }
  public void after(Aspect_List host) { }
  public void after_first(Aspect_List source, Nonempty_Aspect_List dest) { }
  public void after(TVDeclaration_List host) { }
  public void after_first(TVDeclaration_List source, Nonempty_TVDeclaration_List dest) { }
  public void after(SGEdge_SList host) { }
  public void after_first(SGEdge_SList source, Nonempty_SGEdge_SList dest) { }
  public void after(PathSegment_List host) { }
  public void after_first(PathSegment_List source, Nonempty_PathSegment_List dest) { }
  public void after(Strategy_Commalist host) { }
  public void after_first(Strategy_Commalist source, Nonempty_Strategy_Commalist dest) { }
  public void after(NameBinding_Commalist host) { }
  public void after_first(NameBinding_Commalist source, Nonempty_NameBinding_Commalist dest) { }
  public void after(Glob_Commalist host) { }
  public void after_first(Glob_Commalist source, Nonempty_Glob_Commalist dest) { }
  public void after(ClassGlob_Commalist host) { }
  public void after_first(ClassGlob_Commalist source, Nonempty_ClassGlob_Commalist dest) { }
  public void after(Nonempty_Name host) { }
  public void after_it(Nonempty_Name source, Ident dest) { }
  public void after_next(Nonempty_Name source, Nonempty_Name dest) { }
  public void after(Nonempty_DecNodeSetBody_PCList host) { }
  public void after_it(Nonempty_DecNodeSetBody_PCList source, DecNodeSetBody dest) { }
  public void after_next(Nonempty_DecNodeSetBody_PCList source, Nonempty_DecNodeSetBody_PCList dest) { }
  public void after(Nonempty_ClassName_BCList host) { }
  public void after_it(Nonempty_ClassName_BCList source, ClassName dest) { }
  public void after_next(Nonempty_ClassName_BCList source, Nonempty_ClassName_BCList dest) { }
  public void after(Nonempty_Aspect_List host) { }
  public void after_it(Nonempty_Aspect_List source, Aspect dest) { }
  public void after_next(Nonempty_Aspect_List source, Nonempty_Aspect_List dest) { }
  public void after(Nonempty_TVDeclaration_List host) { }
  public void after_it(Nonempty_TVDeclaration_List source, TVDeclaration dest) { }
  public void after_next(Nonempty_TVDeclaration_List source, Nonempty_TVDeclaration_List dest) { }
  public void after(Nonempty_SGEdge_SList host) { }
  public void after_it(Nonempty_SGEdge_SList source, SGEdge dest) { }
  public void after_next(Nonempty_SGEdge_SList source, Nonempty_SGEdge_SList dest) { }
  public void after(Nonempty_PathSegment_List host) { }
  public void after_it(Nonempty_PathSegment_List source, PathSegment dest) { }
  public void after_next(Nonempty_PathSegment_List source, Nonempty_PathSegment_List dest) { }
  public void after(Nonempty_Strategy_Commalist host) { }
  public void after_it(Nonempty_Strategy_Commalist source, Strategy dest) { }
  public void after_next(Nonempty_Strategy_Commalist source, Nonempty_Strategy_Commalist dest) { }
  public void after(Nonempty_NameBinding_Commalist host) { }
  public void after_it(Nonempty_NameBinding_Commalist source, NameBinding dest) { }
  public void after_next(Nonempty_NameBinding_Commalist source, Nonempty_NameBinding_Commalist dest) { }
  public void after(Nonempty_Glob_Commalist host) { }
  public void after_it(Nonempty_Glob_Commalist source, Glob dest) { }
  public void after_next(Nonempty_Glob_Commalist source, Nonempty_Glob_Commalist dest) { }
  public void after(Nonempty_ClassGlob_Commalist host) { }
  public void after_it(Nonempty_ClassGlob_Commalist source, ClassGlob dest) { }
  public void after_next(Nonempty_ClassGlob_Commalist source, Nonempty_ClassGlob_Commalist dest) { }
  public void finish() { }
  void universal_trv0_bef(UniversalVisitor _v_) {  }

  void universal_trv0_aft(UniversalVisitor _v_) {  }

  void universal_trv0(UniversalVisitor _v_) {  }

}
