package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class PathSegment_List implements java.util.Enumeration {
  protected Nonempty_PathSegment_List first;
  public Nonempty_PathSegment_List get_first() { return first; }
  public void set_first(Nonempty_PathSegment_List new_first) { first = new_first; }
  public PathSegment_List() { super(); }
  public PathSegment_List(Nonempty_PathSegment_List first) {
    super();
    set_first(first);
  }
  public static PathSegment_List parse(java.io.Reader in) throws ParseException { return new Parser(in)._PathSegment_List(); }
  public static PathSegment_List parse(java.io.InputStream in) throws ParseException { return new Parser(in)._PathSegment_List(); }
  public static PathSegment_List parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    if (first != null) {
      ((UniversalVisitor) _v_).before_first(this, first);
      first.universal_trv0(_v_);
      ((UniversalVisitor) _v_).after_first(this, first);
    }
    universal_trv0_aft(_v_);
  }


  private Nonempty_PathSegment_List tail;
  public void addElement(PathSegment e) { 
    checktail(); 
    if (tail == null) {
      first = new Nonempty_PathSegment_List(e,null); tail = first;
    } else {
	tail.set_next(new Nonempty_PathSegment_List(e,null)); tail = tail.get_next();
    }
  }

  public void push(PathSegment e) { first = new Nonempty_PathSegment_List(e,first); }

  public java.util.Enumeration elements() { return new PathSegment_List(first); } 

  public int size() {
    int i= 0;
    for (java.util.Enumeration e=elements(); e.hasMoreElements(); i++)
	e.nextElement();
    return i;
  }
  public boolean isEmpty() { return (first == null); }

  public boolean hasMoreElements() { return (first != null); }

  public Object nextElement() {
    PathSegment car = first.get_it();
    first = first.get_next();
    return (Object) car;
  }

  private void checktail() {
    if (tail == null && first != null) {
	tail = first;
	while (tail.get_next() != null) tail = tail.get_next();
    }
  }
  public boolean contains(PathSegment e) {
    java.util.Enumeration en = this.elements();
    while (en.hasMoreElements())
	if (e.equals((PathSegment) en.nextElement())) return true;
    return false;
  }

}
