package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
abstract class SourceDirective {
  protected ClassGlobSpec sources;
  public ClassGlobSpec get_sources() { return sources; }
  public void set_sources(ClassGlobSpec new_sources) { sources = new_sources; }
  public SourceDirective() { super(); }
  public SourceDirective(ClassGlobSpec sources) {
    super();
    set_sources(sources);
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
  }

  void universal_trv0(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before_sources(this, sources);
    sources.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_sources(this, sources);
  }

}
