package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
public abstract class SimpleStrategy extends Strategy {
  protected NameMap parsedNameMap;
  public NameMap get_parsedNameMap() { return parsedNameMap; }
  public void set_parsedNameMap(NameMap new_parsedNameMap) { parsedNameMap = new_parsedNameMap; }
  public SimpleStrategy() { super(); }
  public SimpleStrategy(NameMap parsedNameMap) {
    super();
    set_parsedNameMap(parsedNameMap);
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    super.universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
    super.universal_trv0_aft(_v_);
  }

  void universal_trv0(UniversalVisitor _v_) {
    if (parsedNameMap != null) {
      ((UniversalVisitor) _v_).before_parsedNameMap(this, parsedNameMap);
      parsedNameMap.universal_trv0(_v_);
      ((UniversalVisitor) _v_).after_parsedNameMap(this, parsedNameMap);
    }
    super.universal_trv0(_v_);
  }

}
