package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class AspectCD extends AspectBody {
  protected AspectName aspectname;
  public AspectName get_aspectname() { return aspectname; }
  public void set_aspectname(AspectName new_aspectname) { aspectname = new_aspectname; }
  protected CDBody cdbody;
  public CDBody get_cdbody() { return cdbody; }
  public void set_cdbody(CDBody new_cdbody) { cdbody = new_cdbody; }
  public AspectCD() { super(); }
  public AspectCD(AspectName aspectname, CDBody cdbody) {
    super();
    set_aspectname(aspectname);
    set_cdbody(cdbody);
  }
  public static AspectCD parse(java.io.Reader in) throws ParseException { return new Parser(in)._AspectCD(); }
  public static AspectCD parse(java.io.InputStream in) throws ParseException { return new Parser(in)._AspectCD(); }
  public static AspectCD parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    super.universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
    super.universal_trv0_aft(_v_);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_aspectname(this, aspectname);
    aspectname.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_aspectname(this, aspectname);
    ((UniversalVisitor) _v_).before_cdbody(this, cdbody);
    cdbody.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_cdbody(this, cdbody);
    super.universal_trv0(_v_);
    universal_trv0_aft(_v_);
  }

}
