package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class NameBinding {
  protected Name sgName;
  public Name get_sgName() { return sgName; }
  public void set_sgName(Name new_sgName) { sgName = new_sgName; }
  protected ClassGlobSpec cgNames;
  public ClassGlobSpec get_cgNames() { return cgNames; }
  public void set_cgNames(ClassGlobSpec new_cgNames) { cgNames = new_cgNames; }
  public NameBinding() { super(); }
  public NameBinding(Name sgName, ClassGlobSpec cgNames) {
    super();
    set_sgName(sgName);
    set_cgNames(cgNames);
  }
  public static NameBinding parse(java.io.Reader in) throws ParseException { return new Parser(in)._NameBinding(); }
  public static NameBinding parse(java.io.InputStream in) throws ParseException { return new Parser(in)._NameBinding(); }
  public static NameBinding parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_sgName(this, sgName);
    sgName.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_sgName(this, sgName);
    ((UniversalVisitor) _v_).before_cgNames(this, cgNames);
    cgNames.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_cgNames(this, cgNames);
    universal_trv0_aft(_v_);
  }

}
