package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class ClassNameSet extends Simple {
  protected ClassName_BCList items;
  public ClassName_BCList get_items() { return items; }
  public void set_items(ClassName_BCList new_items) { items = new_items; }
  public ClassNameSet() { super(); }
  public ClassNameSet(ClassName_BCList items) {
    super();
    set_items(items);
  }
  public static ClassNameSet parse(java.io.Reader in) throws ParseException { return new Parser(in)._ClassNameSet(); }
  public static ClassNameSet parse(java.io.InputStream in) throws ParseException { return new Parser(in)._ClassNameSet(); }
  public static ClassNameSet parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }

    List eval(){
        List t = new ArrayList();
        for(Enumeration e = items.elements(); e.hasMoreElements();)
            t.add(e.nextElement().toString());
        return t;
    }

  void universal_trv0_bef(UniversalVisitor _v_) {
    super.universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
    super.universal_trv0_aft(_v_);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_items(this, items);
    items.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_items(this, items);
    super.universal_trv0(_v_);
    universal_trv0_aft(_v_);
  }

}
