package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class DecNodeSet extends TVDeclarationBody {
  protected NodeSubsetName nodesubsetname;
  public NodeSubsetName get_nodesubsetname() { return nodesubsetname; }
  public void set_nodesubsetname(NodeSubsetName new_nodesubsetname) { nodesubsetname = new_nodesubsetname; }
  protected DecNodeSetBody decnodesetbody;
  public DecNodeSetBody get_decnodesetbody() { return decnodesetbody; }
  public void set_decnodesetbody(DecNodeSetBody new_decnodesetbody) { decnodesetbody = new_decnodesetbody; }
  public DecNodeSet() { super(); }
  public DecNodeSet(NodeSubsetName nodesubsetname, DecNodeSetBody decnodesetbody) {
    super();
    set_nodesubsetname(nodesubsetname);
    set_decnodesetbody(decnodesetbody);
  }
  public static DecNodeSet parse(java.io.Reader in) throws ParseException { return new Parser(in)._DecNodeSet(); }
  public static DecNodeSet parse(java.io.InputStream in) throws ParseException { return new Parser(in)._DecNodeSet(); }
  public static DecNodeSet parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }

    List eval(){
        return decnodesetbody.eval();
    }

  void universal_trv0_bef(UniversalVisitor _v_) {
    super.universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
    super.universal_trv0_aft(_v_);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_nodesubsetname(this, nodesubsetname);
    nodesubsetname.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_nodesubsetname(this, nodesubsetname);
    ((UniversalVisitor) _v_).before_decnodesetbody(this, decnodesetbody);
    decnodesetbody.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_decnodesetbody(this, decnodesetbody);
    super.universal_trv0(_v_);
    universal_trv0_aft(_v_);
  }

}
