package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class SubclassGlob extends EdgeGlob {
  protected SourceGlob source;
  public SourceGlob get_source() { return source; }
  public void set_source(SourceGlob new_source) { source = new_source; }
  protected TargetGlob target;
  public TargetGlob get_target() { return target; }
  public void set_target(TargetGlob new_target) { target = new_target; }
  public SubclassGlob() { super(); }
  public SubclassGlob(SourceGlob source, TargetGlob target) {
    super();
    set_source(source);
    set_target(target);
  }
  public static SubclassGlob parse(java.io.Reader in) throws ParseException { return new Parser(in)._SubclassGlob(); }
  public static SubclassGlob parse(java.io.InputStream in) throws ParseException { return new Parser(in)._SubclassGlob(); }
  public static SubclassGlob parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    super.universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
    super.universal_trv0_aft(_v_);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_source(this, source);
    source.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_source(this, source);
    ((UniversalVisitor) _v_).before_target(this, target);
    target.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_target(this, target);
    super.universal_trv0(_v_);
    universal_trv0_aft(_v_);
  }

}
