/*
 *
 */
package CSU670_Plugin;

import java.util.*;
import java.util.List;

import edu.neu.ccs.demeter.aplib.EdgeI;

/**
 * @author jansel
 */
public class TraversalHighlight {
	  	private List _nodes;
	  	private List _edges;
	  	public TraversalHighlight(){
	  		_nodes=new ArrayList();
	  		_edges=new ArrayList();
	  	}
	  	public void addNode(String s){ _nodes.add(s); }
	  	public void addNodes(List n){
	  		for(Iterator i = n.iterator(); i.hasNext();)
	  			addNode(i.next().toString());
	  	}
	  	public void addEdge(EdgeI e){ _edges.add(e); }
	  	public List nodes(){ return _nodes; }
	  	public List edges(){ return _edges; }
}
