package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
abstract class Constraint {
  protected GlobSpec glob;
  public GlobSpec get_glob() { return glob; }
  public void set_glob(GlobSpec new_glob) { glob = new_glob; }
  public Constraint() { super(); }
  public Constraint(GlobSpec glob) {
    super();
    set_glob(glob);
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
  }

  void universal_trv0(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before_glob(this, glob);
    glob.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_glob(this, glob);
  }

}
