package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class DecStrategy extends TVDeclarationBody {
  protected DecName decname;
  public DecName get_decname() { return decname; }
  public void set_decname(DecName new_decname) { decname = new_decname; }
  protected StrategyExpression strategyexpression;
  public StrategyExpression get_strategyexpression() { return strategyexpression; }
  public void set_strategyexpression(StrategyExpression new_strategyexpression) { strategyexpression = new_strategyexpression; }
  public DecStrategy() { super(); }
  public DecStrategy(DecName decname, StrategyExpression strategyexpression) {
    super();
    set_decname(decname);
    set_strategyexpression(strategyexpression);
  }
  public static DecStrategy parse(java.io.Reader in) throws ParseException { return new Parser(in)._DecStrategy(); }
  public static DecStrategy parse(java.io.InputStream in) throws ParseException { return new Parser(in)._DecStrategy(); }
  public static DecStrategy parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    super.universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
    super.universal_trv0_aft(_v_);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_decname(this, decname);
    decname.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_decname(this, decname);
    ((UniversalVisitor) _v_).before_strategyexpression(this, strategyexpression);
    strategyexpression.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_strategyexpression(this, strategyexpression);
    super.universal_trv0(_v_);
    universal_trv0_aft(_v_);
  }

}
