/* Generated By:JavaCC: Do not edit this line. ParserConstants.java */
package CSU670_Plugin.gen;

public interface ParserConstants {

  int EOF = 0;
  int DECIMAL_LITERAL = 50;
  int HEX_LITERAL = 51;
  int OCTAL_LITERAL = 52;
  int FLOATING_POINT_LITERAL = 53;
  int EXPONENT = 54;
  int CHARACTER_LITERAL = 55;
  int STRING_LITERAL = 56;
  int TEXT_LITERAL = 57;
  int TRUE = 58;
  int FALSE = 59;
  int IDENTIFIER = 60;
  int LETTER = 61;
  int DIGIT = 62;
  int LINE = 63;
  int WORD = 68;

  int DEFAULT = 0;
  int Line = 1;
  int Word = 2;

  String[] tokenImage = {
    "<EOF>",
    "\"aspect\"",
    "\"(\"",
    "\"ClassDictionary\"",
    "\")\"",
    "\"Traversal\"",
    "\"{\"",
    "\"}\"",
    "\"declare\"",
    "\";\"",
    "\"chosen\"",
    "\"selector\"",
    "\":\"",
    "\"class\"",
    "\"dictionary\"",
    "\"strategy\"",
    "\"node\"",
    "\"set\"",
    "\"or\"",
    "\"and\"",
    "\"!\"",
    "\"nodes\"",
    "\"regexp\"",
    "\"*\"",
    "\"XYZ*\"",
    "\"with\"",
    "\"->\"",
    "\"source:\"",
    "\"target:\"",
    "\"from\"",
    "\"through\"",
    "\"via\"",
    "\"bypassing\"",
    "\"only-through\"",
    "\"to\"",
    "\"to-stop\"",
    "\",\"",
    "\"join\"",
    "\"merge\"",
    "\"intersect\"",
    "\"=\"",
    "\"=>\"",
    "\":>\"",
    "\".\"",
    "\" \"",
    "\"\\t\"",
    "\"\\n\"",
    "\"\\r\"",
    "<token of kind 48>",
    "<token of kind 49>",
    "<DECIMAL_LITERAL>",
    "<HEX_LITERAL>",
    "<OCTAL_LITERAL>",
    "<FLOATING_POINT_LITERAL>",
    "<EXPONENT>",
    "<CHARACTER_LITERAL>",
    "<STRING_LITERAL>",
    "<TEXT_LITERAL>",
    "\"true\"",
    "\"false\"",
    "<IDENTIFIER>",
    "<LETTER>",
    "<DIGIT>",
    "<LINE>",
    "\" \"",
    "\"\\t\"",
    "\"\\n\"",
    "\"\\r\"",
    "<WORD>",
  };

}
