package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class TVDeclaration {
  protected TVDeclarationBody tvdeclarationbody;
  public TVDeclarationBody get_tvdeclarationbody() { return tvdeclarationbody; }
  public void set_tvdeclarationbody(TVDeclarationBody new_tvdeclarationbody) { tvdeclarationbody = new_tvdeclarationbody; }
  public TVDeclaration() { super(); }
  public TVDeclaration(TVDeclarationBody tvdeclarationbody) {
    super();
    set_tvdeclarationbody(tvdeclarationbody);
  }
  public static TVDeclaration parse(java.io.Reader in) throws ParseException { return new Parser(in)._TVDeclaration(); }
  public static TVDeclaration parse(java.io.InputStream in) throws ParseException { return new Parser(in)._TVDeclaration(); }
  public static TVDeclaration parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_tvdeclarationbody(this, tvdeclarationbody);
    tvdeclarationbody.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_tvdeclarationbody(this, tvdeclarationbody);
    universal_trv0_aft(_v_);
  }

}
