package CSU670_Plugin.gen;
import edu.neu.ccs.demeter.dj.*;
import edu.neu.ccs.demeter.aplib.cd.ClassDefVisitor;
import edu.neu.ccs.demeter.aplib.cd.ClassDef;
import java.io.*;
import java.util.*;
import edu.neu.ccs.demeter.*;
class TVDeclarations {
  protected TVDeclaration_List tvdeclaration_list;
  public TVDeclaration_List get_tvdeclaration_list() { return tvdeclaration_list; }
  public void set_tvdeclaration_list(TVDeclaration_List new_tvdeclaration_list) { tvdeclaration_list = new_tvdeclaration_list; }
  public TVDeclarations() { super(); }
  public TVDeclarations(TVDeclaration_List tvdeclaration_list) {
    super();
    set_tvdeclaration_list(tvdeclaration_list);
  }
  public static TVDeclarations parse(java.io.Reader in) throws ParseException { return new Parser(in)._TVDeclarations(); }
  public static TVDeclarations parse(java.io.InputStream in) throws ParseException { return new Parser(in)._TVDeclarations(); }
  public static TVDeclarations parse(String s) {
    try { return parse(new java.io.StringReader(s)); }
    catch (ParseException e) {
      throw new RuntimeException(e.toString());
    }
  }
  void universal_trv0_bef(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).before(this);
  }

  void universal_trv0_aft(UniversalVisitor _v_) {
    ((UniversalVisitor) _v_).after(this);
  }

  void universal_trv0(UniversalVisitor _v_) {
    universal_trv0_bef(_v_);
    ((UniversalVisitor) _v_).before_tvdeclaration_list(this, tvdeclaration_list);
    tvdeclaration_list.universal_trv0(_v_);
    ((UniversalVisitor) _v_).after_tvdeclaration_list(this, tvdeclaration_list);
    universal_trv0_aft(_v_);
  }

}
